@@ -33,17 +33,18 @@
 #include <config-kleopatra.h>
 
 #include "exportcertificatecommand.h"
+#include "fileoperationspreferences.h"
 
 #include "command_p.h"
 
 #include <dialogs/exportcertificatesdialog.h>
 
-#include <utils/classify.h>
 #include <utils/filedialog.h>
 
-#include <Libkleo/CryptoBackend>
-#include <Libkleo/CryptoBackendFactory>
-#include <Libkleo/ExportJob>
+#include <Libkleo/Classify>
+
+#include <QGpgME/Protocol>
+#include <QGpgME/ExportJob>
 
 #include <gpgme++/key.h>
 
@@ -53,7 +54,6 @@
 #include <QMap>
 #include <QPointer>
 
-#include <boost/bind.hpp>
 #include <algorithm>
 #include <vector>
 #include <cassert>
@@ -61,7 +61,7 @@
 using namespace Kleo;
 using namespace Kleo::Dialogs;
 using namespace GpgME;
-using namespace boost;
+using namespace QGpgME;
 
 class ExportCertificateCommand::Private : public Command::Private
 {
@@ -78,7 +78,7 @@ public:
     void exportResult(const GpgME::Error &, const QByteArray &);
     void showError(const GpgME::Error &error);
 
-    bool requestFileNames(Protocol prot);
+    bool requestFileNames(GpgME::Protocol prot);
     void finishedIfLastJob();
 
 private:
@@ -161,8 +161,10 @@ void ExportCertificateCommand::doStart()
         return;
     }
 
-    const std::vector<Key>::iterator firstCms = std::partition(keys.begin(), keys.end(), boost::bind(&GpgME::Key::protocol, _1) != CMS);
-
+    const auto firstCms = std::partition(keys.begin(), keys.end(),
+                                         [](const GpgME::Key &key) {
+                                            return key.protocol() != GpgME::CMS;
+                                         });
     std::vector<Key> openpgp, cms;
     std::copy(keys.begin(), firstCms, std::back_inserter(openpgp));
     std::copy(firstCms, keys.end(), std::back_inserter(cms));
@@ -208,14 +210,16 @@ bool ExportCertificateCommand::Private::requestFileNames(GpgME::Protocol protoco
     }
 
     QString proposedFileName;
-    if (keys().size() == 1)
+    if (keys().size() == 1) {
+        const bool usePGPFileExt = FileOperationsPreferences().usePGPFileExt();
         proposedFileName
             = QString::fromLatin1(keys().front().primaryFingerprint())
               + QLatin1Char('.')
               + QString::fromLatin1(outputFileExtension(protocol == OpenPGP
                                     ? Class::OpenPGP | Class::Ascii | Class::Certificate
-                                    : Class::CMS | Class::Ascii | Class::Certificate))
+                                    : Class::CMS | Class::Ascii | Class::Certificate, usePGPFileExt))
               ;
+    }
 
     const QString fname = FileDialog::getSaveFileNameEx(parentWidgetOrView(),
                           i18n("Export Certificates"),
@@ -232,7 +236,7 @@ void ExportCertificateCommand::Private::startExportJob(GpgME::Protocol protocol,
 {
     assert(protocol != GpgME::UnknownProtocol);
 
-    const CryptoBackend::Protocol *const backend = CryptoBackendFactory::instance()->protocol(protocol);
+    const QGpgME::Protocol *const backend = (protocol == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
     assert(backend);
     const QString fileName = fileNames[protocol];
     const bool binary = protocol == GpgME::OpenPGP
