@@ -43,8 +43,6 @@
 #include "assuancommand.h"
 #include "sessiondata.h"
 
-#include <models/keycache.h> // :(
-
 #include <utils/input.h>
 #include <utils/output.h>
 #include <utils/gnupg-helper.h>
@@ -56,6 +54,7 @@
 
 #include <Libkleo/Stl_Util>
 #include <Libkleo/Exception>
+#include <Libkleo/KeyCache>
 
 #include <gpgme++/data.h>
 #include <gpgme++/key.h>
@@ -77,19 +76,13 @@
 
 #include <kleo-assuan.h>
 
-#ifndef Q_MOC_RUN // QTBUG-22829
-#include <boost/type_traits/remove_pointer.hpp>
-#include <boost/lexical_cast.hpp>
-#include <boost/bind.hpp>
-#include <boost/mem_fn.hpp>
-#include <boost/mpl/if.hpp>
-#endif
-
 #include <vector>
 #include <map>
 #include <string>
 #include <memory>
 #include <algorithm>
+#include <functional>
+#include <type_traits>
 
 #include <errno.h>
 
@@ -105,7 +98,6 @@
 # include <unistd.h>
 #endif
 using namespace Kleo;
-using namespace boost;
 
 static const unsigned int INIT_SOCKET_FLAGS = 3; // says info assuan...
 //static int(*USE_DEFAULT_HANDLER)(assuan_context_t,char*) = 0;
@@ -121,8 +113,8 @@ static void my_assuan_release(assuan_context_t ctx)
 }
 
 #endif
-// shared_ptr for assuan_context_t w/ deleter enforced to assuan_deinit_server:
-typedef shared_ptr< remove_pointer<assuan_context_t>::type > AssuanContextBase;
+// std::shared_ptr for assuan_context_t w/ deleter enforced to assuan_deinit_server:
+typedef std::shared_ptr<std::remove_pointer<assuan_context_t>::type> AssuanContextBase;
 struct AssuanContext : AssuanContextBase {
     AssuanContext() : AssuanContextBase() {}
 #ifndef HAVE_ASSUAN2
@@ -259,7 +251,7 @@ class AssuanServerConnection::Private : public QObject
     friend class ::Kleo::AssuanCommand;
     AssuanServerConnection *const q;
 public:
-    Private(assuan_fd_t fd_, const std::vector< shared_ptr<AssuanCommandFactory> > &factories_, AssuanServerConnection *qq);
+    Private(assuan_fd_t fd_, const std::vector< std::shared_ptr<AssuanCommandFactory> > &factories_, AssuanServerConnection *qq);
     ~Private();
 
 Q_SIGNALS:
@@ -292,9 +284,10 @@ public Q_SLOTS:
 private:
     void nohupDone(AssuanCommand *cmd)
     {
-        const std::vector< shared_ptr<AssuanCommand> >::iterator it
-            = std::find_if(nohupedCommands.begin(), nohupedCommands.end(),
-                           boost::bind(&shared_ptr<AssuanCommand>::get, _1) == cmd);
+        const auto it = std::find_if(nohupedCommands.begin(), nohupedCommands.end(),
+                                     [cmd](const std::shared_ptr<AssuanCommand> &other) {
+                                        return other.get() == cmd;
+                                     });
         assert(it != nohupedCommands.end());
         nohupedCommands.erase(it);
         if (nohupedCommands.empty() && closed) {
@@ -507,7 +500,8 @@ private:
         return assuan_process_done(ctx_, 0);
     }
 
-    template <bool in> struct Input_or_Output : mpl::if_c<in, Input, Output> {};
+    template <bool in>
+    struct Input_or_Output : std::conditional<in, Input, Output> {};
 
     // format: TAG (FD|FD=\d+|FILE=...)
     template <bool in, typename T_memptr>
@@ -537,7 +531,7 @@ private:
                 throw gpg_error(GPG_ERR_ASS_SYNTAX);
             }
 
-            shared_ptr< typename Input_or_Output<in>::type > io;
+            std::shared_ptr< typename Input_or_Output<in>::type > io;
 
             if (options.count("FD")) {
 
@@ -555,9 +549,9 @@ private:
                     }
                 } else {
 #if defined(Q_OS_WIN32)
-                    fd = (assuan_fd_t)lexical_cast<intptr_t>(fdstr);
+                    fd = (assuan_fd_t)std::stoi(fdstr);
 #else
-                    fd = lexical_cast<assuan_fd_t>(fdstr);
+                    fd = std::stoi(fdstr);
 #endif
                 }
 
@@ -813,7 +807,9 @@ private:
         QStringList sl;
         std::transform(c.begin(), c.end(),
                        std::back_inserter(sl),
-                       boost::bind(&KMime::Types::Mailbox::prettyAddress, _1));
+                       [](typename T_container::const_reference val) {
+                           return val.prettyAddress();
+                       });
         return dumpStringList(sl);
     }
 
@@ -830,7 +826,7 @@ private:
     QByteArray dumpMementos() const
     {
         QByteArray result;
-        for (std::map< QByteArray, shared_ptr<AssuanCommand::Memento> >::const_iterator it = mementos.begin(), end = mementos.end(); it != end; ++it) {
+        for (std::map< QByteArray, std::shared_ptr<AssuanCommand::Memento> >::const_iterator it = mementos.begin(), end = mementos.end(); it != end; ++it) {
             char buf[2 + 2 * sizeof(void *) + 2];
             sprintf(buf, "0x%p\n", (void *)it->second.get());
             buf[sizeof(buf) - 1] = '\0';
@@ -841,7 +837,10 @@ private:
 
     QByteArray dumpFiles() const
     {
-        return dumpStringList(kdtools::copy<QStringList>(files));
+        QStringList rv;
+        rv.reserve(files.size());
+        std::copy(files.cbegin(), files.cend(), std::back_inserter(rv));
+        return dumpStringList(rv);
     }
 
     void cleanup();
@@ -856,14 +855,11 @@ private:
         sessionId = 0;
         mementos.clear();
         files.clear();
-        std::for_each(inputs.begin(), inputs.end(),
-                      boost::bind(&Input::finalize, _1));
+        std::for_each(inputs.begin(), inputs.end(), std::mem_fn(&Input::finalize));
         inputs.clear();
-        std::for_each(outputs.begin(), outputs.end(),
-                      boost::bind(&Output::finalize, _1));
+        std::for_each(outputs.begin(), outputs.end(), std::mem_fn(&Output::finalize));
         outputs.clear();
-        std::for_each(messages.begin(), messages.end(),
-                      boost::bind(&Input::finalize, _1));
+        std::for_each(messages.begin(), messages.end(), std::mem_fn(&Input::finalize));
         messages.clear();
         bias = GpgME::UnknownProtocol;
     }
@@ -879,16 +875,16 @@ private:
     GpgME::Protocol bias;
     QString sessionTitle;
     unsigned int sessionId;
-    std::vector< shared_ptr<QSocketNotifier> > notifiers;
-    std::vector< shared_ptr<AssuanCommandFactory> > factories; // sorted: _detail::ByName<std::less>
-    shared_ptr<AssuanCommand> currentCommand;
-    std::vector< shared_ptr<AssuanCommand> > nohupedCommands;
+    std::vector< std::shared_ptr<QSocketNotifier> > notifiers;
+    std::vector< std::shared_ptr<AssuanCommandFactory> > factories; // sorted: _detail::ByName<std::less>
+    std::shared_ptr<AssuanCommand> currentCommand;
+    std::vector< std::shared_ptr<AssuanCommand> > nohupedCommands;
     std::map<std::string, QVariant> options;
     std::vector<KMime::Types::Mailbox> senders, recipients;
-    std::vector< shared_ptr<Input> > inputs, messages;
-    std::vector< shared_ptr<Output> > outputs;
+    std::vector< std::shared_ptr<Input> > inputs, messages;
+    std::vector< std::shared_ptr<Output> > outputs;
     std::vector<QString> files;
-    std::map< QByteArray, shared_ptr<AssuanCommand::Memento> > mementos;
+    std::map< QByteArray, std::shared_ptr<AssuanCommand::Memento> > mementos;
 };
 
 void AssuanServerConnection::Private::cleanup()
@@ -903,7 +899,7 @@ void AssuanServerConnection::Private::cleanup()
     fd = ASSUAN_INVALID_FD;
 }
 
-AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector< shared_ptr<AssuanCommandFactory> > &factories_, AssuanServerConnection *qq)
+AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector< std::shared_ptr<AssuanCommandFactory> > &factories_, AssuanServerConnection *qq)
     : QObject(),
       q(qq),
       fd(fd_),
@@ -956,14 +952,14 @@ AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector< sha
     assert(numFDs != -1);   // == 1
 
     if (!numFDs || fds[0] != fd) {
-        const shared_ptr<QSocketNotifier> sn(new QSocketNotifier((intptr_t)fd, QSocketNotifier::Read), mem_fn(&QObject::deleteLater));
+        const std::shared_ptr<QSocketNotifier> sn(new QSocketNotifier((intptr_t)fd, QSocketNotifier::Read), std::mem_fn(&QObject::deleteLater));
         connect(sn.get(), &QSocketNotifier::activated, this, &Private::slotReadActivity);
         notifiers.push_back(sn);
     }
 
     notifiers.reserve(notifiers.size() + numFDs);
     for (int i = 0; i < numFDs; ++i) {
-        const shared_ptr<QSocketNotifier> sn(new QSocketNotifier((intptr_t)fds[i], QSocketNotifier::Read), mem_fn(&QObject::deleteLater));
+        const std::shared_ptr<QSocketNotifier> sn(new QSocketNotifier((intptr_t)fds[i], QSocketNotifier::Read), std::mem_fn(&QObject::deleteLater));
         connect(sn.get(), &QSocketNotifier::activated, this, &Private::slotReadActivity);
         notifiers.push_back(sn);
     }
@@ -995,7 +991,7 @@ AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector< sha
         throw Exception(err, "register \"FILE\" handler");
 
     // register user-defined commands:
-    Q_FOREACH (shared_ptr<AssuanCommandFactory> fac, factories)
+    Q_FOREACH (std::shared_ptr<AssuanCommandFactory> fac, factories)
 #ifndef HAVE_ASSUAN2
         if (const gpg_error_t err = assuan_register_command(ctx.get(), fac->name(), fac->_handler()))
 #else
@@ -1070,7 +1066,7 @@ AssuanServerConnection::Private::~Private()
     cleanup();
 }
 
-AssuanServerConnection::AssuanServerConnection(assuan_fd_t fd, const std::vector< shared_ptr<AssuanCommandFactory> > &factories, QObject *p)
+AssuanServerConnection::AssuanServerConnection(assuan_fd_t fd, const std::vector< std::shared_ptr<AssuanCommandFactory> > &factories, QObject *p)
     : QObject(p), d(new Private(fd, factories, this))
 {
 
@@ -1170,8 +1166,8 @@ public:
     }
 
     std::map<std::string, QVariant> options;
-    std::vector< shared_ptr<Input> > inputs, messages;
-    std::vector< shared_ptr<Output> > outputs;
+    std::vector< std::shared_ptr<Input> > inputs, messages;
+    std::vector< std::shared_ptr<Output> > outputs;
     std::vector<QString> files;
     std::vector<KMime::Types::Mailbox> recipients, senders;
     bool informativeRecipients, informativeSenders;
@@ -1272,7 +1268,7 @@ std::vector<U> keys(const std::map<U, V> &map)
 }
 }
 
-const std::map< QByteArray, shared_ptr<AssuanCommand::Memento> > &AssuanCommand::mementos() const
+const std::map< QByteArray, std::shared_ptr<AssuanCommand::Memento> > &AssuanCommand::mementos() const
 {
     // oh, hack :(
     assert(assuan_get_pointer(d->ctx.get()));
@@ -1289,31 +1285,31 @@ bool AssuanCommand::hasMemento(const QByteArray &tag) const
     }
 }
 
-shared_ptr<AssuanCommand::Memento> AssuanCommand::memento(const QByteArray &tag) const
+std::shared_ptr<AssuanCommand::Memento> AssuanCommand::memento(const QByteArray &tag) const
 {
     if (const unsigned int id = sessionId()) {
-        const shared_ptr<SessionDataHandler> sdh = SessionDataHandler::instance();
-        const shared_ptr<SessionData> sd = sdh->sessionData(id);
-        const std::map< QByteArray, shared_ptr<Memento> >::const_iterator it = sd->mementos.find(tag);
+        const std::shared_ptr<SessionDataHandler> sdh = SessionDataHandler::instance();
+        const std::shared_ptr<SessionData> sd = sdh->sessionData(id);
+        const std::map< QByteArray, std::shared_ptr<Memento> >::const_iterator it = sd->mementos.find(tag);
         if (it != sd->mementos.end()) {
             return it->second;
         }
     }
-    const std::map< QByteArray, shared_ptr<Memento> >::const_iterator it = mementos().find(tag);
+    const std::map< QByteArray, std::shared_ptr<Memento> >::const_iterator it = mementos().find(tag);
     if (it == mementos().end()) {
-        return shared_ptr<Memento>();
+        return std::shared_ptr<Memento>();
     } else {
         return it->second;
     }
 }
 
-QByteArray AssuanCommand::registerMemento(const shared_ptr<Memento> &mem)
+QByteArray AssuanCommand::registerMemento(const std::shared_ptr<Memento> &mem)
 {
     const QByteArray tag = QByteArray::number(reinterpret_cast<qulonglong>(mem.get()), 36);
     return registerMemento(tag, mem);
 }
 
-QByteArray AssuanCommand::registerMemento(const QByteArray &tag, const shared_ptr<Memento> &mem)
+QByteArray AssuanCommand::registerMemento(const QByteArray &tag, const std::shared_ptr<Memento> &mem)
 {
     // oh, hack :(
     assert(assuan_get_pointer(d->ctx.get()));
@@ -1339,24 +1335,27 @@ void AssuanCommand::removeMemento(const QByteArray &tag)
     }
 }
 
-const std::vector< shared_ptr<Input> > &AssuanCommand::inputs() const
+const std::vector< std::shared_ptr<Input> > &AssuanCommand::inputs() const
 {
     return d->inputs;
 }
 
-const std::vector< shared_ptr<Input> > &AssuanCommand::messages() const
+const std::vector< std::shared_ptr<Input> > &AssuanCommand::messages() const
 {
     return d->messages;
 }
 
-const std::vector< shared_ptr<Output> > &AssuanCommand::outputs() const
+const std::vector< std::shared_ptr<Output> > &AssuanCommand::outputs() const
 {
     return d->outputs;
 }
 
 QStringList AssuanCommand::fileNames() const
 {
-    return kdtools::copy<QStringList>(d->files);
+    QStringList rv;
+    rv.reserve(d->files.size());
+    std::copy(d->files.cbegin(), d->files.cend(), std::back_inserter(rv));
+    return rv;
 }
 
 unsigned int AssuanCommand::numFiles() const
@@ -1445,12 +1444,9 @@ void AssuanCommand::done(const GpgME::Error &err)
 
     d->done = true;
 
-    std::for_each(d->messages.begin(), d->messages.end(),
-                  boost::bind(&Input::finalize, _1));
-    std::for_each(d->inputs.begin(), d->inputs.end(),
-                  boost::bind(&Input::finalize, _1));
-    std::for_each(d->outputs.begin(), d->outputs.end(),
-                  boost::bind(&Output::finalize, _1));
+    std::for_each(d->messages.begin(), d->messages.end(), std::mem_fn(&Input::finalize));
+    std::for_each(d->inputs.begin(), d->inputs.end(), std::mem_fn(&Input::finalize));
+    std::for_each(d->outputs.begin(), d->outputs.end(), std::mem_fn(&Output::finalize));
     d->messages.clear();
     d->inputs.clear();
     d->outputs.clear();
@@ -1532,13 +1528,13 @@ gpg_error_t AssuanCommandFactory::_handle(assuan_context_t ctx, char *line, cons
 
     try {
 
-        const std::vector< shared_ptr<AssuanCommandFactory> >::const_iterator it
+        const std::vector< std::shared_ptr<AssuanCommandFactory> >::const_iterator it
             = std::lower_bound(conn.factories.begin(), conn.factories.end(), commandName, _detail::ByName<std::less>());
         kleo_assert(it != conn.factories.end());
         kleo_assert(*it);
         kleo_assert(qstricmp((*it)->name(), commandName) == 0);
 
-        const shared_ptr<AssuanCommand> cmd = (*it)->create();
+        const std::shared_ptr<AssuanCommand> cmd = (*it)->create();
         kleo_assert(cmd);
 
         cmd->d->ctx     = conn.ctx;
@@ -1594,7 +1590,7 @@ int AssuanServerConnection::Private::startCommandBottomHalf()
         return 0;
     }
 
-    const shared_ptr<AssuanCommand> cmd = currentCommand;
+    const std::shared_ptr<AssuanCommand> cmd = currentCommand;
     if (!cmd) {
         return 0;
     }
